@@ -26,10 +26,10 @@ simAdditive <- function(newdata, mu, parameter, covtype, cl, iso=FALSE, eps.R =
   }
   #building R
   for (j in 1:ncl) { 
-    cor.str <- DiceKriging::covStruct.create(covtype = covtype, d = length(cl[[j]]), 
+    cor.str <- covStruct.create(covtype = covtype, d = length(cl[[j]]), 
             var.names = NULL, known.covparam = "All", coef.cov = thetalist[[j]], 
             coef.var = alpha[j], iso = iso[j])
-    R <- R + DiceKriging::covMatrix(object = cor.str, X = as.matrix(newdata[, cl[[j]]]))[[1]]
+    R <- R + covMatrix(object = cor.str, X = as.matrix(newdata[, cl[[j]]]))[[1]]
   }
   R <- R + diag(eps.R, n, n)
   whitenoise <- rnorm(n)
